<?php

use yii\db\Migration;

class m130524_201442_init extends Migration
{
    public function up()
    {
        $tableOptions = null;
        if ($this->db->driverName === 'mysql') {
            // http://stackoverflow.com/questions/766809/whats-the-difference-between-utf8-general-ci-and-utf8-unicode-ci
            $tableOptions = 'CHARACTER SET utf8 COLLATE utf8_unicode_ci ENGINE=InnoDB';
        }

        $this->createTable('{{%user}}', [
            'id' => $this->primaryKey(),
            'username' => $this->string()->notNull()->unique(),
            'auth_key' => $this->string(32)->notNull(),
            'password_hash' => $this->string()->notNull(),
            'password_reset_token' => $this->string()->unique(),
            'email' => $this->string()->notNull()->unique(),
            'avatar' => $this->string()->defaultValue(''),
            'status' => $this->smallInteger()->notNull()->defaultValue(10),
            'created_at' => $this->integer()->notNull(),
            'updated_at' => $this->integer()->notNull(),
        ], $tableOptions);
        $this->batchInsert("{{%user}}", ['id','username','auth_key','password_hash','email','status','created_at','updated_at',],
            [
                [
                    '1',
                    'aaa',
                    'y-I4ci4glWqom_ZeW6IItOCWFx69FjqQ',
                    '$2y$13$h2GSh/y8qa1WU.ZRVU3VaOr2/Zfh/VxCUfLmbY4xNeZ1Ql2lbMF36',
                    'aaa@feehi.com',
                    '10',
                    '1469070407',
                    '0',
                ],
                [
                    '2',
                    'bbb',
                    '9wMhzQEqGW8h1_NFBoCYY3StQ_ZJ8UaM',
                    '$2y$13$MbDa4j1TujVid9Zk0saOYu7eGk/N52nOJjTYr22dCYRhJ/D9jV29.',
                    'bbb@feehi.com',
                    '10',
                    '1469070568',
                    '0',
                ],
            ]
        );

        $this->createTable('{{%admin_user}}', [
            'id' => $this->primaryKey()->unsigned(),
            'username' => $this->string()->notNull()->unique(),
            'auth_key' => $this->string(32)->notNull(),
            'password_hash' => $this->string()->notNull(),
            'password_reset_token' => $this->string()->unique(),
            'email' => $this->string()->notNull()->unique(),
            'avatar' => $this->string()->defaultValue(''),
            'status' => $this->smallInteger()->notNull()->defaultValue(10),
            'created_at' => $this->integer()->notNull(),
            'updated_at' => $this->integer()->defaultValue(0),
        ], $tableOptions);
        $this->batchInsert("{{%admin_user}}", ['id','username','auth_key','password_hash','email','avatar','status','created_at','updated_at'],
            [
                [
                    '1',
                    'admin',
                    'zr9mY7lt23oAhj_ZYjydbLJKcbE3FJ19',
                    '$2y$13$8aF72c/7Nqq/atyMivhVTej0bIXS1t8daPJXKtVjFzJUsG68eGgaG',
                    'admin@feehi.com',
                    '',
                    '10',
                    '1468288038',
                    '0',
                ],
                [
                    '2',
                    'fff',
                    '1JC2paBZhxrLPXNEpGDqW8Bp130x0_g6',
                    '$2y$13$v.WxC/zKWasDR2fVZsa5u.xoVCh.8VE1QtyqCQNFrZO7DgEvZoZhS',
                    'fff@feehi.com',
                    '',
                    '10',
                    '1469087451',
                    '0',
                ],
            ]
        );

        $this->createTable('{{%admin_log}}', [
            'id' => $this->primaryKey()->unsigned(),
            'user_id' => $this->integer()->unsigned()->notNull(),
            'route' => $this->string()->defaultValue(''),
            'description' => $this->text(),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->addForeignKey('fk_user_id', "{{%admin_log}}", "user_id", "{{admin_user}}", "id", "CASCADE", "CASCADE");


        $this->createTable('{{%admin_role_user}}', [
            'id' => $this->primaryKey()->unsigned(),
            'uid' => $this->integer()->unsigned()->notNull(),
            'role_id' => $this->integer()->unsigned()->notNull(),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->addForeignKey('fk_uid', "{{%admin_role_user}}", "uid", "{{%admin_user}}", "id", "CASCADE", "CASCADE");

        $this->createTable('{{%admin_roles}}', [
            'id' => $this->primaryKey()->unsigned(),
            'parent_id' => $this->integer()->unsigned()->defaultValue(0),
            'role_name' => $this->string()->notNull(),
            'remark' => $this->string()->defaultValue(''),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->batchInsert("{{%admin_roles}}", ['id','parent_id','role_name','created_at','updated_at','remark'],
            [
                [
                    '1',
                    '0',
                    '超级管理员',
                    '1468309347',
                    '0',
                    '拥有所有权限',
                ],
                [
                    '2',
                    '0',
                    '编辑',
                    '1468309363',
                    '1469070673',
                    '拥有seo设置，文章添加、修改、编辑、删除的权限',
                ],
            ]
        );

        $this->createTable('{{%category}}', [
            'id' => $this->primaryKey()->unsigned(),
            'parent_id' => $this->integer()->unsigned()->defaultValue(0),
            'name' => $this->string()->notNull(),
            'sort' => $this->integer()->unsigned()->defaultValue(0),
            'remark' => $this->string()->defaultValue(''),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->batchInsert("{{%category}}", ['id','parent_id','name','sort','created_at','updated_at','remark'],
            [
                [
                    '1',
                    '0',
                    'php',
                    '0',
                    '1468293958',
                    '0',
                    '',
                ],
                [
                    '2',
                    '0',
                    'java',
                    '0',
                    '1468293965',
                    '0',
                    '',
                ],
                [
                    '3',
                    '0',
                    'javascript',
                    '0',
                    '1468293974',
                    '0',
                    '',
                ],
            ]
        );

        $this->createTable('{{%article}}', [
            'id' => $this->primaryKey()->unsigned(),
            'cid' => $this->integer()->unsigned()->defaultValue(0),
            'type' => $this->integer()->unsigned()->defaultValue(0),
            'title' => $this->string()->notNull(),
            'sub_title' => $this->string()->defaultValue(''),
            'summary' => $this->string()->defaultValue(''),
            'thumb' => $this->string()->defaultValue(''),
            'seo_title' => $this->string()->defaultValue(''),
            'seo_keywords' => $this->string()->defaultValue(''),
            'seo_description' => $this->string()->defaultValue(''),
            'status' => $this->smallInteger()->unsigned()->defaultValue(1),
            'sort' => $this->integer()->unsigned()->defaultValue(0),
            'author_id' => $this->integer()->unsigned()->defaultValue(0),
            'author_name' => $this->string()->defaultValue(''),
            'scan_count' => $this->integer()->unsigned()->defaultValue(0),
            'comment_count' => $this->integer()->unsigned()->defaultValue(0),
            'can_comment' => $this->smallInteger()->unsigned()->defaultValue(1),
            'visibility' => $this->smallInteger()->unsigned()->defaultValue(1),
            'tag' => $this->string()->defaultValue(''),
            'flag_headline' => $this->smallInteger()->unsigned()->defaultValue(0),
            'flag_recommend' => $this->smallInteger()->unsigned()->defaultValue(0),
            'flag_slide_show' => $this->smallInteger()->unsigned()->defaultValue(0),
            'flag_special_recommend' => $this->smallInteger()->unsigned()->defaultValue(0),
            'flag_roll' => $this->smallInteger()->unsigned()->defaultValue(0),
            'flag_bold' => $this->smallInteger()->unsigned()->defaultValue(0),
            'flag_picture' => $this->smallInteger()->unsigned()->defaultValue(0),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
       // $this->addForeignKey("fk_cid", "{{%article}}", "cid", "{{%category}}", "id", "CASCADE", "CASCADE");
        $this->createIndex("index_title", "{{%article}}",['title', 'cid', 'tag']);
        $this->batchInsert("{{%article}}",[
            'id','cid','type','title','sub_title','summary','thumb','seo_title','seo_keywords','seo_description','status','sort','author_id','author_name','scan_count','comment_count','can_comment','visibility','tag','flag_headline','flag_recommend','flag_slide_show','flag_special_recommend','flag_roll','flag_bold','flag_picture','created_at','updated_at'] ,
            [
                [
                    '1',
                    '3',
                    '0',
                    '高效快速地加载 AngularJS 视图',
                    '',
                    '当AngularJS应用程序变大时，很多问题就开始显现出来了，比如多层级视图的加载问题，如果在子视图显示之前没有预加载，则可能在需要展示时，发生视觉闪烁的情况。这种问题在网络缓慢，或者服务器使用较慢的https连接时更容易出现。',
                    '###~SITEURL~###/uploads/article/thumb/2016071211354628.jpg',
                    '高效快速地加载 AngularJS 视图',
                    'JavaScript, AngularJS',
                    '当AngularJS应用程序变大时，很多问题就开始显现出来了，比如多层级视图的加载问题，如果在子视图显示之前没有预加载，则可能在需要展示时，发生视觉闪烁的情况。这种问题在网络缓慢，或者服务器使用较慢的https连接时更容易出现。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'JavaScript,AngularJS',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468294546',
                    '1468294568',
                ],
                [
                    '2',
                    '3',
                    '0',
                    '如何定位 Node.js 的内存泄漏',
                    '',
                    '在 《一次 Node.js 应用内存暴涨分析》中，我们处理了一个 Node.js vm 引发的内存泄漏问题，处理过程也是比较艰辛。而在我们实际开发中，可能经常会碰到内存泄漏的问题，但很多情况下，我们对于这种问题的处理是有些迷茫的，没有一定的操作流程，效率比较低。虽然这种问题对于经验的要求比较高，但如果有一个简单的排查流程，还是会有一定帮助的。',
                    '###~SITEURL~###/uploads/article/thumb/201607121141407.png',
                    '',
                    '',
                    '在 《一次 Node.js 应用内存暴涨分析》中，我们处理了一个 Node.js vm 引发的内存泄漏问题，处理过程也是比较艰辛。而在我们实际开发中，可能经常会碰到内存泄漏的问题，但很多情况下，我们对于这种问题的处理是有些迷茫的，没有一定的操作流程，效率比较低。虽然这种问题对于经验的要求比较高，但如果有一个简单的排查流程，还是会有一定帮助的。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '3',
                    '0',
                    '1',
                    '0',
                    '',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '1468294900',
                    '1468301331',
                ],
                [
                    '3',
                    '1',
                    '0',
                    'Hack：用于HHVM的一种新编程语言',
                    '',
                    '',
                    '###~SITEURL~###/uploads/article/thumb/2016071212382956.jpg',
                    '',
                    'Facebook, hack, php',
                    '',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'Facebook, hack, php',
                    '0',
                    '0',
                    '0',
                    '1',
                    '1',
                    '0',
                    '0',
                    '1468298309',
                    '1468301305',
                ],
                [
                    '4',
                    '3',
                    '0',
                    '抛弃jQuery，拥抱原生JavaScript',
                    '',
                    '原生javascript',
                    '###~SITEURL~###/uploads/article/thumb/2016071212414099.png',
                    '抛弃jQuery，拥抱原生JavaScript',
                    'jquery,javascript,web',
                    '',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    '',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468298500',
                    '0',
                ],
                [
                    '5',
                    '2',
                    '0',
                    '[JAVA · 初级]：GC-垃圾回收机制',
                    '',
                    '在C++中，对象所占的内存在程序结束运行之前一直被占用，在明确释放之前不能分配给其它对象；而在Java中，当没有对象引用指向原先分配给某个对象的内存时，该内存便成为垃圾。',
                    '###~SITEURL~###/uploads/article/thumb/2016071212441669.jpg',
                    '[JAVA · 初级]：GC-垃圾回收机制',
                    'gc,垃圾回收,java',
                    '在C++中，对象所占的内存在程序结束运行之前一直被占用，在明确释放之前不能分配给其它对象；而在Java中，当没有对象引用指向原先分配给某个对象的内存时，该内存便成为垃圾。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'gc,垃圾回收,java',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468298628',
                    '1468299738',
                ],
                [
                    '6',
                    '1',
                    '0',
                    'PHP 7.0.2正式版发布：WordPress速度提升3倍！',
                    '',
                    '提到PHP，肯定会有人说这是世界上最好的编程语言。',
                    '###~SITEURL~###/uploads/article/thumb/2016071212472374.jpeg',
                    'PHP 7.0.2正式版发布：WordPress速度提升3倍！',
                    'php7,php,wordpress',
                    '提到PHP，肯定会有人说这是世界上最好的编程语言。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    'php7,php,wordpress',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468298843',
                    '0',
                ],
                [
                    '7',
                    '3',
                    '0',
                    '为何要学HTML5开发?HTML5发展前景如何？',
                    '',
                    '',
                    '',
                    '为何要学HTML5开发?HTML5发展前景如何？',
                    'html,html5',
                    '',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    '',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468298894',
                    '1468298938',
                ],
                [
                    '8',
                    '2',
                    '0',
                    'Spring知识点提炼',
                    '',
                    'spring框架',
                    '###~SITEURL~###/uploads/article/thumb/2016071212525610.jpg',
                    'Spring知识点提炼',
                    'spring,java',
                    'spring框架',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'spring,java',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '1468299176',
                    '1468301374',
                ],
                [
                    '9',
                    '3',
                    '0',
                    'CSS代码重构与优化之路',
                    '',
                    '着项目规模的增加，项目中的CSS代码也会越来越多，如果没有及时对CSS代码进行维护，CSS代码不断会越来越多。',
                    '###~SITEURL~###/uploads/article/thumb/2016071212553820.jpeg',
                    'CSS代码重构与优化之路',
                    'css,重构',
                    '着项目规模的增加，项目中的CSS代码也会越来越多，如果没有及时对CSS代码进行维护，CSS代码不断会越来越多。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'css,重构',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468299338',
                    '0',
                ],
                [
                    '10',
                    '1',
                    '0',
                    'PHP分页技术的代码和示例',
                    '',
                    '分页是目前在显示大量结果时所采用的最好的方式。',
                    '###~SITEURL~###/uploads/article/thumb/2016071212580919.png',
                    'PHP分页技术的代码和示例',
                    'php,分页,php分页',
                    '分页是目前在显示大量结果时所采用的最好的方式。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    'php,分页',
                    '0',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '0',
                    '1468299489',
                    '1468301281',
                ],
                [
                    '11',
                    '1',
                    '0',
                    '10个免费下载PHP脚本的网站',
                    '',
                    '免费的PHP脚本下载',
                    '###~SITEURL~###/uploads/article/thumb/2016071213000120.png',
                    '10个免费下载PHP脚本的网站',
                    'php脚本,下载,代码下载',
                    '免费的PHP脚本下载',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '4',
                    '1',
                    '1',
                    '0',
                    'php脚本,下载,代码下载',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468299601',
                    '1468301148',
                ],
                [
                    '12',
                    '1',
                    '0',
                    '趣文：如果编程语言是女人（新编版）',
                    '',
                    '语言趣文',
                    '###~SITEURL~###/uploads/article/thumb/2016071213020658.png',
                    '趣文：如果编程语言是女人（新编版）',
                    'java, Javascript, Lisp, php, Python, Ruby, 编程语言, 趣文',
                    '语言趣文',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'java, Javascript, Lisp, php, Python, Ruby, 编程语言, 趣文',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '1468299726',
                    '1468301362',
                ],
                [
                    '13',
                    '3',
                    '0',
                    '浏览器缓存机制',
                    '',
                    '浏览器缓存机制，其实主要就是HTTP协议定义的缓存机制（如： Expires； Cache-control等）。',
                    '###~SITEURL~###/uploads/article/thumb/2016071213054793.jpg',
                    '浏览器缓存机制',
                    '缓存,浏览器缓存,http协议',
                    '浏览器缓存机制，其实主要就是HTTP协议定义的缓存机制（如： Expires； Cache-control等）。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    '缓存,浏览器缓存,http协议',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468299947',
                    '1468303626',
                ],
                [
                    '14',
                    '3',
                    '0',
                    'JavaScript 统治的世界，烤面包机将能运行 JS 了',
                    '',
                    '从浏览器到手机，从平板电脑到桌面电脑，从工业自动化到最小的微控制器——最近JavaScript 似乎蔓延到了最意想不到的地方，不远的将来，你的烤面包机也将会运行 JavaScript ……。但是为什么？',
                    '',
                    'JavaScript 统治的世界，烤面包机将能运行 JS 了',
                    'javascript,流行',
                    '从浏览器到手机，从平板电脑到桌面电脑，从工业自动化到最小的微控制器——最近JavaScript 似乎蔓延到了最意想不到的地方，不远的将来，你的烤面包机也将会运行 JavaScript ……。但是为什么？',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    'javascript,流行',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300042',
                    '0',
                ],
                [
                    '15',
                    '2',
                    '0',
                    '给Java说句公道话',
                    '',
                    '有些人问我，在现有的语言里面，有什么好的推荐？我说：“Java。” 他们很惊讶：“什么？Java！” 所以我现在来解释一下。',
                    '###~SITEURL~###/uploads/article/thumb/2016071213095350.jpg',
                    '给Java说句公道话',
                    'java',
                    '有些人问我，在现有的语言里面，有什么好的推荐？我说：“Java。” 他们很惊讶：“什么？Java！” 所以我现在来解释一下。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'java',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300193',
                    '1468301238',
                ],
                [
                    '16',
                    '2',
                    '0',
                    'Java编程入门（1.6）：现代用户界面',
                    '',
                    '算机刚问世时，普通人——包括大多数程序员——都不允许靠近计算机。',
                    '###~SITEURL~###/uploads/article/thumb/2016071214100948.jpg',
                    'Java编程入门（1.6）：现代用户界面',
                    'java,用户界面',
                    '算机刚问世时，普通人——包括大多数程序员——都不允许靠近计算机。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    'java,用户界面',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300356',
                    '1468303809',
                ],
                [
                    '17',
                    '3',
                    '0',
                    '精简页面的样式文件，去掉不用的样式',
                    '',
                    '精简css样式',
                    '',
                    '精简页面的样式文件，去掉不用的样式',
                    'css,样式',
                    '精简css样式',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '6',
                    '2',
                    '1',
                    '0',
                    'css,样式',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300509',
                    '0',
                ],
                [
                    '18',
                    '2',
                    '0',
                    'Java编程入门：前言',
                    '',
                    'Java编程入门》是一本使用Java作为入门语言的免费计算机编程课本',
                    '###~SITEURL~###/uploads/article/thumb/2016071213165538.jpg',
                    'Java编程入门：前言',
                    'java,入门,编程书籍',
                    'Java编程入门》是一本使用Java作为入门语言的免费计算机编程课本',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'java,入门,编程书籍',
                    '0',
                    '0',
                    '0',
                    '1',
                    '0',
                    '0',
                    '0',
                    '1468300615',
                    '1468301270',
                ],
                [
                    '19',
                    '2',
                    '0',
                    'Java 8最快的垃圾搜集器是什么？',
                    '',
                    'OpenJDK 8 有多种 GC（Garbage Collector）算法，如 Parallel GC、CMS 和 G1。哪一个才是最快的呢？如果在 Java 9 中将 Java 8 默认的 GC 从 Parallel GC 改为 G1 （目前只是建议）将会怎么样呢？让我们对此进行基准测试。',
                    '###~SITEURL~###/uploads/article/thumb/2016071213182356.jpg',
                    'Java 8最快的垃圾搜集器是什么？',
                    'java,java8,垃圾收集',
                    'OpenJDK 8 有多种 GC（Garbage Collector）算法，如 Parallel GC、CMS 和 G1。哪一个才是最快的呢？如果在 Java 9 中将 Java 8 默认的 GC 从 Parallel GC 改为 G1 （目前只是建议）将会怎么样呢？让我们对此进行基准测试。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '33',
                    '7',
                    '1',
                    '0',
                    'java,java8,垃圾收集',
                    '0',
                    '0',
                    '0',
                    '1',
                    '1',
                    '0',
                    '0',
                    '1468300703',
                    '1468301343',
                ],
                [
                    '20',
                    '2',
                    '0',
                    '使用Memcached改进Java企业级应用性能（1）：架构和设置',
                    '',
                    'Memcached由Danga Interactive开发，用来提升LiveJournal.com网站性能。Memcached分布式架构支持众多的社交网络应用，Twitter、Facebook还有Wikipedia。在接下来的两部分教程中，Sunil Patil介绍了Memcached分布式哈希表架构，以及利用它帮助你为数据驱动Java企业应用做数据缓存。',
                    '###~SITEURL~###/uploads/article/thumb/201607121325288.png',
                    '使用Memcached改进Java企业级应用性能（1）：架构和设置',
                    'java,memcached',
                    'Memcached由Danga Interactive开发，用来提升LiveJournal.com网站性能。Memcached分布式架构支持众多的社交网络应用，Twitter、Facebook还有Wikipedia。在接下来的两部分教程中，Sunil Patil介绍了Memcached分布式哈希表架构，以及利用它帮助你为数据驱动Java企业应用做数据缓存。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '1',
                    '0',
                    '1',
                    '0',
                    'jvm,java',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300831',
                    '1468303452',
                ],
                [
                    '21',
                    '2',
                    '0',
                    'JVM的相关知识整理和学习',
                    '',
                    '诺依曼体系结构中，指出计算机处理的数据和指令都是二进制数，采用存储程序方式不加区分的存储在同一个存储器里，并且顺序执行，指令由操作码和地址码组成，操作码决定了操作类型和所操作的数的数字类型，地址码则指出地址码和操作数。',
                    '###~SITEURL~###/uploads/article/thumb/2016071213203123.jpg',
                    'JVM的相关知识整理和学习',
                    'jvm,java',
                    '诺依曼体系结构中，指出计算机处理的数据和指令都是二进制数，采用存储程序方式不加区分的存储在同一个存储器里，并且顺序执行，指令由操作码和地址码组成，操作码决定了操作类型和所操作的数的数字类型，地址码则指出地址码和操作数。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'jvm,java',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300831',
                    '1468300844',
                ],
                [
                    '22',
                    '2',
                    '0',
                    '关于Java集合的小抄',
                    '',
                    '在尽可能短的篇幅里，将所有集合与并发集合的特征，实现方式，性能捋一遍。适合所有”精通Java”其实还不那么自信的人阅读。',
                    '###~SITEURL~###/uploads/article/thumb/2016071213224495.jpg',
                    '关于Java集合的小抄',
                    'java,java集合',
                    '在尽可能短的篇幅里，将所有集合与并发集合的特征，实现方式，性能捋一遍。适合所有”精通Java”其实还不那么自信的人阅读。',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    'java,java集合',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468300964',
                    '1468300981',
                ],
                [
                    '23',
                    '0',
                    '2',
                    '关于我们',
                    'about',
                    '',
                    '',
                    '',
                    '',
                    '',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    '',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468309252',
                    '0',
                ],
                [
                    '24',
                    '0',
                    '2',
                    '联系方式',
                    'contact',
                    '',
                    '',
                    '',
                    '',
                    '',
                    '1',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '0',
                    '',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468309318',
                    '0',
                ],
                [
                    '25',
                    '0',
                    '0',
                    'dfdf',
                    'dfd',
                    'fsafsdfsdf',
                    '',
                    '',
                    '',
                    '',
                    '0',
                    '0',
                    '1',
                    'admin',
                    '0',
                    '0',
                    '1',
                    '',
                    '',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '0',
                    '1468898361',
                    '1470111146',
                ],
            ]
        );

        $this->createTable('{{%article_content}}', [
            'id' => $this->primaryKey()->unsigned(),
            'aid' => $this->integer()->unsigned()->defaultValue(0),
            'content' => "LongText",
        ], $tableOptions);
        $this->addForeignKey('fk_aid', "{{%article_content}}", "aid", "{{%article}}", "id", "CASCADE", "CASCADE");
        //$this->batchInsert("{{%article_content}}", ['id','aid','content'], require(__DIR__.'/article.php'));
        $contents = require(__DIR__.'/article.php');
        foreach($contents as $v){
            $this->insert("{{%article_content}}", ['aid'=>$v[1], 'content'=>$v[2]]);
        }

        $this->createTable('{{%comment}}', [
            'id' => $this->primaryKey()->unsigned(),
            'aid' => $this->integer()->unsigned()->defaultValue(0),
            'uid' => $this->integer()->unsigned()->defaultValue(0),
            'reply_to' => $this->integer()->unsigned()->defaultValue(0),
            'nickname' => $this->string()->defaultValue('游客'),
            'email' => $this->string()->defaultValue(''),
            'website_url' => $this->string()->defaultValue(''),
            'content' => $this->string()->notNull(),
            'ip' => $this->string()->defaultValue(''),
            'status' => $this->smallInteger()->unsigned()->defaultValue(0),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->batchInsert("{{%comment}}", ['id','aid','uid','reply_to','nickname','email','website_url','content','ip','status','created_at','updated_at'],
            [
                [
                    "1",
                    "25",
                    "0",
                    "0",
                    "aaa",
                    "",
                    "",
                    "你好，世界！",
                    "127.0.0.1",
                    "1",
                    "1476066961",
                    "0",

                ],
                [
                    "2",
                    "22",
                    "0",
                    "0",
                    "aaa",
                    "",
                    "",
                    " <img src='http://cms.test.local/static/images/smilies/icon_biggrin.gif'>  <img src='http://cms.test.local/static/images/smilies/icon_mrgreen.gif'>  <img src='http://cms.test.local/static/images/smilies/icon_redface.gif'> 哎哟，不错哟~",
                    "127.0.0.1",
                    "1",
                    "1476066990",
                    "0",

                ],
                [
                    "3",
                    "22",
                    "0",
                    "2",
                    "bbb",
                    "",
                    "",
                    "呵呵哒",
                    "127.0.0.1",
                    "1",
                    "1476067011",
                    "0",

                ],
                [
                    "4",
                    "25",
                    "0",
                    "0",
                    "ccc",
                    "",
                    "",
                    " <img src='http://cms.test.local/static/images/smilies/icon_cool.gif'> ",
                    "127.0.0.1",
                    "1",
                    "1476067042",
                    "0",

                ],
                [
                    "5",
                    "25",
                    "0",
                    "0",
                    "aaa",
                    "",
                    "",
                    "嘻嘻嘻",
                    "127.0.0.1",
                    "1",
                    "1476067060",
                    "0",

                ],
                [
                    "6",
                    "21",
                    "0",
                    "0",
                    "aaa",
                    "",
                    "",
                    "流弊哄哄~~~",
                    "127.0.0.1",
                    "1",
                    "1476067093",
                    "0",

                ],
            ]
        );

        $this->createTable('{{%friend_link}}', [
            'id' => $this->primaryKey()->unsigned(),
            'name' => $this->string()->notNull(),
            'image' => $this->string()->defaultValue(''),
            'url' => $this->string()->defaultValue(''),
            'target' => $this->string()->defaultValue('_blank'),
            'sort' => $this->integer()->unsigned()->defaultValue(0),
            'status' => $this->smallInteger()->unsigned()->defaultValue(0),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->batchInsert("{{friend_link}}", ['id','name','image','url','target','sort','status','created_at','updated_at'],
            [
                [
                    '1',
                    '飞嗨博客',
                    '',
                    'http://blog.feehi.com',
                    '_blank',
                    '0',
                    '1',
                    '1468303851',
                    '0',
                ],
                [
                    '2',
                    '飞嗨网',
                    '',
                    'http://www.feehi.com',
                    '_blank',
                    '0',
                    '1',
                    '1468303882',
                    '0',
                ],
                [
                    '3',
                    '36kr',
                    '',
                    'http://www.36kr.com',
                    '_blank',
                    '0',
                    '1',
                    '1468303902',
                    '0',
                ],
                [
                    '4',
                    '破晓电影',
                    '',
                    'http://www.poxiao.com',
                    '_blank',
                    '0',
                    '1',
                    '1468303938',
                    '0',
                ],
                [
                    '5',
                    '翠竹林主题',
                    '',
                    'http://www.cuizl.com/',
                    '_blank',
                    '0',
                    '1',
                    '1468303974',
                    '0',
                ],
            ]
        );

        $this->createTable('{{%menu}}', [
            'id' => $this->primaryKey()->unsigned(),
            'type' => $this->integer()->unsigned()->defaultValue(0),
            'parent_id' => $this->integer()->unsigned()->defaultValue(0),
            'name' => $this->string()->notNull(),
            'url' => $this->string()->notNull(),
            'icon' => $this->string()->defaultValue(''),
            'sort' => $this->integer()->unsigned()->defaultValue(0),
            'target' => $this->string()->defaultValue('_blank'),
            'is_absolute_url' => $this->smallInteger()->unsigned()->defaultValue(0),
            'is_display' => $this->smallInteger()->unsigned()->defaultValue(1),
            'method' => "enum('all','post','get') default 'all'",
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->createIndex("index_name", "{{%menu}}", "name");
        $this->createIndex("index_url", "{{%menu}}", "url");
        $this->createIndex("index_method", "{{%menu}}", "method");
        $this->batchInsert("{{%menu}}", [
        'id','type','parent_id','name','url','icon','sort','target','is_absolute_url','is_display','method','created_at','updated_at'
        ],
         [
             [
                 "1",
                 "0",
                 "0",
                 "设置",
                 "setting",
                 "fa fa fa-cogs",
                 "1",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470064425",
                 "1476070842",

             ],
             [
                 "2",
                 "0",
                 "1",
                 "网站设置",
                 "setting/website",
                 "",
                 "0",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470064528",
                 "0",

             ],
             [
                 "3",
                 "0",
                 "1",
                 "seo设置",
                 "setting/seo",
                 "",
                 "0",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470064574",
                 "0",

             ],
             [
                 "4",
                 "0",
                 "1",
                 "自定义设置",
                 "setting/custom",
                 "",
                 "0",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470064600",
                 "0",

             ],
             [
                 "5",
                 "0",
                 "0",
                 "菜单",
                 "menu",
                 "fa fa fa-th-list",
                 "2",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470064761",
                 "1476070842",

             ],
             [
                 "6",
                 "0",
                 "5",
                 "前台菜单",
                 "frontend-menu/index",
                 "",
                 "0",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470064785",
                 "0",

             ],
             [
                 "7",
                 "0",
                 "5",
                 "后台菜单",
                 "menu/index",
                 "",
                 "0",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470064803",
                 "0",

             ],
             [
                 "8",
                 "0",
                 "0",
                 "内容",
                 "article",
                 "fa fa fa-edit",
                 "3",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470064850",
                 "1476070842",

             ],
             [
                 "9",
                 "0",
                 "8",
                 "文章",
                 "article/index",
                 "",
                 "0",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470065005",
                 "0",

             ],
             [
                 "10",
                 "0",
                 "8",
                 "评论",
                 "comment/index",
                 "",
                 "0",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470065043",
                 "0",

             ],
             [
                 "11",
                 "0",
                 "8",
                 "单页",
                 "page/index",
                 "",
                 "0",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470065084",
                 "0",

             ],
             [
                 "12",
                 "0",
                 "8",
                 "分类",
                 "category/index",
                 "",
                 "0",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470065111",
                 "0",

             ],
             [
                 "13",
                 "0",
                 "0",
                 "用户",
                 "user/index",
                 "fa fa-users",
                 "4",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470065584",
                 "1476070842",

             ],
             [
                 "14",
                 "0",
                 "0",
                 "权限",
                 "rbac",
                 "fa fa-shield",
                 "5",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470065608",
                 "1476070842",

             ],
             [
                 "15",
                 "0",
                 "14",
                 "管理员",
                 "admin-user/index",
                 "",
                 "0",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470065672",
                 "0",

             ],
             [
                 "16",
                 "0",
                 "14",
                 "角色",
                 "admin-roles/index",
                 "",
                 "0",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470065689",
                 "0",

             ],
             [
                 "17",
                 "0",
                 "0",
                 "友情链接",
                 "friend-link/index",
                 "fa fa-link",
                 "6",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470065784",
                 "1476070842",

             ],
             [
                 "18",
                 "0",
                 "0",
                 "日志",
                 "log/index",
                 "fa fa-history",
                 "8",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470065819",
                 "1476070842",

             ],
             [
                 "19",
                 "1",
                 "0",
                 "首页",
                 "/",
                 "",
                 "0",
                 "_self",
                 "0",
                 "1",
                 "all",
                 "1470111187",
                 "0",

             ],
             [
                 "20",
                 "1",
                 "0",
                 "php",
                 "cat/php",
                 "",
                 "0",
                 "_self",
                 "0",
                 "1",
                 "all",
                 "1470111200",
                 "0",

             ],
             [
                 "21",
                 "1",
                 "0",
                 "java",
                 "cat/java",
                 "",
                 "0",
                 "_self",
                 "0",
                 "1",
                 "all",
                 "1470111209",
                 "0",

             ],
             [
                 "22",
                 "1",
                 "0",
                 "javascript",
                 "cat/javascript",
                 "",
                 "0",
                 "_self",
                 "0",
                 "1",
                 "all",
                 "1470111222",
                 "0",

             ],
             [
                 "23",
                 "0",
                 "0",
                 "附件管理",
                 "file/index",
                 "fa fa-files-o",
                 "7",
                 "_blank",
                 "0",
                 "1",
                 "all",
                 "1470065608",
                 "1476070842",

             ],
         ]
        );

        $this->createTable('{{%admin_role_permission}}', [
            'id' => $this->primaryKey()->unsigned(),
            'role_id' => $this->integer()->unsigned()->notNull(),
            'menu_id' => $this->integer()->unsigned()->notNull(),
            'name' => $this->string()->notNull(),
            'url' => $this->string()->notNull(),
            'method' => "enum('all','post','get') default 'all'",
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->addForeignKey('fk_menu_id', "{{%admin_role_permission}}", "menu_id", "{{%menu}}", "id", "CASCADE", "CASCADE");
        $this->addForeignKey('fk_menu_name', "{{%admin_role_permission}}", "name", "{{%menu}}", "name", "CASCADE", "CASCADE");
        $this->addForeignKey('fk_url', "{{%admin_role_permission}}", "url", "{{%menu}}", "url", "CASCADE", "CASCADE");
        $this->addForeignKey('fk_method', "{{%admin_role_permission}}", "method", "{{%menu}}", "method", "CASCADE", "CASCADE");
        $this->addForeignKey('fk_role_id', "{{%admin_role_permission}}", "role_id", "{{%admin_roles}}", "id", "CASCADE", "CASCADE");
        $this->batchInsert("{{%admin_role_permission}}", ['id','role_id','menu_id','name','url', 'method', 'created_at','updated_at'],
            [
                [
                    '62',
                    '1',
                    '3',
                    'seo设置',
                    'setting/seo',
                    'all',
                    '1470069312',
                    '0',
                ],
                [
                    '68',
                    '1',
                    '9',
                    '文章',
                    'article/index',
                    'all',
                    '1470069312',
                    '0',
                ],
                [
                    '69',
                    '1',
                    '10',
                    '评论',
                    'comment/index',
                    'all',
                    '1470069312',
                    '0',
                ],
                [
                    '78',
                    '2',
                    '1',
                    '设置',
                    'setting',
                    'all',
                    '1470069344',
                    '0',
                ],
                [
                    '79',
                    '2',
                    '3',
                    'seo设置',
                    'setting/seo',
                    'all',
                    '1470069344',
                    '0',
                ],
                [
                    '80',
                    '2',
                    '8',
                    '内容',
                    'article',
                    'all',
                    '1470069344',
                    '0',
                ],
                [
                    '81',
                    '2',
                    '9',
                    '文章',
                    'article/index',
                    'all',
                    '1470069344',
                    '0',
                ],
                [
                    '82',
                    '2',
                    '10',
                    '评论',
                    'comment/index',
                    'all',
                    '1470069344',
                    '0',
                ],
            ]
        );

        $this->createTable('{{%options}}', [
            'id' => $this->primaryKey()->unsigned(),
            'type' => $this->integer()->unsigned()->defaultValue(0),
            'name' => $this->string()->notNull(),
            'value' => $this->text(),
            'input_type' => $this->smallInteger()->unsigned()->defaultValue(1),
            'autoload' => $this->smallInteger()->unsigned()->defaultValue(1),
            'tips' => $this->string()->defaultValue(''),
            'sort' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->batchInsert(
            "{{%options}}",
            [
                'id','type','name','value','input_type','tips','autoload','sort'],
            [
                [
                    '1',
                    '0',
                    'seo_title',
                    'feehi cms',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '2',
                    '0',
                    'seo_keywords',
                    '飞嗨,cms,yii2,php,feehi cms',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '3',
                    '0',
                    'seo_description',
                    'Feehi CMS，最好的cms之一',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '4',
                    '0',
                    'website_title',
                    'Feehi CMS',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '5',
                    '0',
                    'website_description',
                    'Based on most popular php framework yii2',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '6',
                    '0',
                    'website_email',
                    'admin@feehi.com',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '7',
                    '0',
                    'website_language',
                    'zh-CN',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '8',
                    '0',
                    'website_icp',
                    '粤ICP备15018643号',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '9',
                    '0',
                    'website_statics_script',
                    '',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '10',
                    '0',
                    'website_status',
                    '1',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '11',
                    '0',
                    'website_comment',
                    '1',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '12',
                    '0',
                    'website_comment_need_verify',
                    '0',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '13',
                    '0',
                    'website_timezone',
                    'Asia/Shanghai',
                    '1',
                    '',
                    '0',
                    '0',
                ],
                [
                    '14',
                    '1',
                    'qq',
                    '1838889850',
                    '1',
                    'QQ号码',
                    '1',
                    '0',
                ],
            ]
        );

        $this->createTable('{{%file}}', [
            'id' => $this->primaryKey()->unsigned(),
            'uri' => $this->string()->notNull(),
            'filename' => $this->string()->notNull(),
            'mime' => $this->string()->defaultValue(''),
            'filesize' => $this->integer()->unsigned()->defaultValue(0),
            'status' => $this->smallInteger()->unsigned()->defaultValue(0),
            'created_at' => $this->integer()->unsigned()->notNull(),
            'updated_at' => $this->integer()->unsigned()->defaultValue(0),
        ], $tableOptions);
        $this->batchInsert('{{%file}}', ['id','uri','filename','mime','filesize','status','created_at','updated_at'], [
            [
                "1",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294426924927.jpg",
                "1468294426924927.jpg",
                "image/jpeg",
                "63123",
                "1",
                "1476070309",
                "1476070309",

            ],
            [
                "2",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294426810816.jpg",
                "1468294426810816.jpg",
                "image/jpeg",
                "76463",
                "1",
                "1476070309",
                "1476070309",

            ],
            [
                "3",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294426337411.jpg",
                "1468294426337411.jpg",
                "image/jpeg",
                "10837",
                "1",
                "1476070309",
                "1476070309",

            ],
            [
                "4",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294426954735.jpg",
                "1468294426954735.jpg",
                "image/jpeg",
                "25607",
                "1",
                "1476070309",
                "1476070309",

            ],
            [
                "5",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294426881975.jpg",
                "1468294426881975.jpg",
                "image/jpeg",
                "21386",
                "1",
                "1476070309",
                "1476070309",

            ],
            [
                "6",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294426283307.jpg",
                "1468294426283307.jpg",
                "image/jpeg",
                "34166",
                "1",
                "1476070309",
                "1476070309",

            ],
            [
                "7",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294426533692.jpg",
                "1468294426533692.jpg",
                "image/jpeg",
                "32863",
                "1",
                "1476070309",
                "1476070309",

            ],
            [
                "8",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294426435233.jpg",
                "1468294426435233.jpg",
                "image/jpeg",
                "27659",
                "1",
                "1476070309",
                "1476070309",

            ],
            [
                "9",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294426495633.jpg",
                "1468294426495633.jpg",
                "image/jpeg",
                "47473",
                "1",
                "1476070309",
                "1476070309",

            ],
            [
                "10",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294426721265.jpg",
                "1468294426721265.jpg",
                "image/jpeg",
                "91086",
                "1",
                "1476070309",
                "1476070309",

            ],
            [
                "11",
                "http://cms.test.local/uploads/article/thumb/2016071211354628.jpg",
                "2016071211354628.jpg",
                "image/jpeg",
                "63123",
                "1",
                "1476070309",
                "1476070309",

            ],
            [
                "12",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294849828901.jpg",
                "1468294849828901.jpg",
                "image/jpeg",
                "569435",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "13",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294849790398.jpg",
                "1468294849790398.jpg",
                "image/jpeg",
                "175235",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "14",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294850103658.jpg",
                "1468294850103658.jpg",
                "image/jpeg",
                "252971",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "15",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294850969854.jpg",
                "1468294850969854.jpg",
                "image/jpeg",
                "333333",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "16",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294850266890.jpg",
                "1468294850266890.jpg",
                "image/jpeg",
                "79375",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "17",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468294850307542.jpg",
                "1468294850307542.jpg",
                "image/jpeg",
                "111051",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "18",
                "http://cms.test.local/uploads/article/thumb/201607121141407.png",
                "201607121141407.png",
                "image/png",
                "1641",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "19",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468298205168464.jpg",
                "1468298205168464.jpg",
                "image/jpeg",
                "31219",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "20",
                "http://cms.test.local/uploads/article/thumb/2016071212382956.jpg",
                "2016071212382956.jpg",
                "image/jpeg",
                "4095",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "21",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468298416352727.png",
                "1468298416352727.png",
                "image/png",
                "60549",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "22",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468298417381609.png",
                "1468298417381609.png",
                "image/png",
                "37301",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "23",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468298417259422.jpg",
                "1468298417259422.jpg",
                "image/jpeg",
                "26578",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "24",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468298417985419.png",
                "1468298417985419.png",
                "image/png",
                "49346",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "25",
                "http://cms.test.local/uploads/article/thumb/2016071212414099.png",
                "2016071212414099.png",
                "image/png",
                "56177",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "26",
                "http://cms.test.local/uploads/article/thumb/2016071212441669.jpg",
                "2016071212441669.jpg",
                "image/jpeg",
                "7882",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "27",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468298771899372.png",
                "1468298771899372.png",
                "image/png",
                "52992",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "28",
                "http://cms.test.local/uploads/article/thumb/2016071212472374.jpeg",
                "2016071212472374.jpeg",
                "image/jpeg",
                "12758",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "29",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468298932286202.jpg",
                "1468298932286202.jpg",
                "image/jpeg",
                "20913",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "30",
                "http://cms.test.local/uploads/article/thumb/2016071212525610.jpg",
                "2016071212525610.jpg",
                "image/jpeg",
                "6556",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "31",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299277464951.jpg",
                "1468299277464951.jpg",
                "image/jpeg",
                "32146",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "32",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299277827321.jpg",
                "1468299277827321.jpg",
                "image/jpeg",
                "19936",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "33",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299277594091.jpg",
                "1468299277594091.jpg",
                "image/jpeg",
                "22705",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "34",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299277383185.jpg",
                "1468299277383185.jpg",
                "image/jpeg",
                "16484",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "35",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299279967847.jpg",
                "1468299279967847.jpg",
                "image/jpeg",
                "26104",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "36",
                "http://cms.test.local/uploads/article/thumb/2016071212553820.jpeg",
                "2016071212553820.jpeg",
                "image/jpeg",
                "13044",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "37",
                "http://cms.test.local/uploads/article/thumb/2016071212580919.png",
                "2016071212580919.png",
                "image/png",
                "99277",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "38",
                "http://cms.test.local/uploads/article/thumb/2016071213000120.png",
                "2016071213000120.png",
                "image/png",
                "141966",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "39",
                "http://cms.test.local/uploads/article/thumb/2016071213020658.png",
                "2016071213020658.png",
                "image/png",
                "160137",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "40",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299838865470.png",
                "1468299838865470.png",
                "image/png",
                "13279",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "41",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299838328238.png",
                "1468299838328238.png",
                "image/png",
                "8110",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "42",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299838884044.png",
                "1468299838884044.png",
                "image/png",
                "20300",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "43",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299838226909.png",
                "1468299838226909.png",
                "image/png",
                "41705",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "44",
                "http://cms.test.local/uploads/article/thumb/2016071213054793.jpg",
                "2016071213054793.jpg",
                "image/jpeg",
                "11588",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "45",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299998418671.jpg",
                "1468299998418671.jpg",
                "image/jpeg",
                "73272",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "46",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299999714651.jpg",
                "1468299999714651.jpg",
                "image/jpeg",
                "90578",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "47",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299999832122.jpg",
                "1468299999832122.jpg",
                "image/jpeg",
                "51898",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "48",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299999441365.jpg",
                "1468299999441365.jpg",
                "image/jpeg",
                "75984",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "49",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299999699135.gif",
                "1468299999699135.gif",
                "image/gif",
                "8796",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "50",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299999452509.gif",
                "1468299999452509.gif",
                "image/gif",
                "5252",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "51",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299999852174.jpg",
                "1468299999852174.jpg",
                "image/jpeg",
                "28757",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "52",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299999742938.jpg",
                "1468299999742938.jpg",
                "image/jpeg",
                "52796",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "53",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299999924948.jpg",
                "1468299999924948.jpg",
                "image/jpeg",
                "21131",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "54",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299999654871.jpg",
                "1468299999654871.jpg",
                "image/jpeg",
                "40273",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "55",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299999584163.jpg",
                "1468299999584163.jpg",
                "image/jpeg",
                "17525",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "56",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299999689916.jpg",
                "1468299999689916.jpg",
                "image/jpeg",
                "78252",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "57",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299999923485.gif",
                "1468299999923485.gif",
                "image/gif",
                "17879",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "58",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468299999116936.jpg",
                "1468299999116936.jpg",
                "image/jpeg",
                "67782",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "59",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300000997206.jpg",
                "1468300000997206.jpg",
                "image/jpeg",
                "50762",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "60",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300000970739.jpg",
                "1468300000970739.jpg",
                "image/jpeg",
                "23500",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "61",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300000715501.jpg",
                "1468300000715501.jpg",
                "image/jpeg",
                "102702",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "62",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300000866115.jpg",
                "1468300000866115.jpg",
                "image/jpeg",
                "16969",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "63",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300000192859.jpg",
                "1468300000192859.jpg",
                "image/jpeg",
                "27757",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "64",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300000718429.jpg",
                "1468300000718429.jpg",
                "image/jpeg",
                "56518",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "65",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300000493427.jpg",
                "1468300000493427.jpg",
                "image/jpeg",
                "53095",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "66",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300000187437.jpg",
                "1468300000187437.jpg",
                "image/jpeg",
                "26246",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "67",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300000441602.jpg",
                "1468300000441602.jpg",
                "image/jpeg",
                "54377",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "68",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300000884072.jpg",
                "1468300000884072.jpg",
                "image/jpeg",
                "31608",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "69",
                "http://cms.test.local/uploads/article/thumb/2016071213095350.jpg",
                "2016071213095350.jpg",
                "image/jpeg",
                "28709",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "70",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300326859862.jpg",
                "1468300326859862.jpg",
                "image/jpeg",
                "47906",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "71",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300326707784.jpg",
                "1468300326707784.jpg",
                "image/jpeg",
                "30599",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "72",
                "http://cms.test.local/uploads/article/thumb/2016071214100948.jpg",
                "2016071214100948.jpg",
                "image/jpeg",
                "14505",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "73",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300460944939.jpg",
                "1468300460944939.jpg",
                "image/jpeg",
                "56563",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "74",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300565664083.jpg",
                "1468300565664083.jpg",
                "image/jpeg",
                "53203",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "75",
                "http://cms.test.local/uploads/article/thumb/2016071213165538.jpg",
                "2016071213165538.jpg",
                "image/jpeg",
                "14435",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "76",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300659144755.jpg",
                "1468300659144755.jpg",
                "image/jpeg",
                "91073",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "77",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300659327903.jpg",
                "1468300659327903.jpg",
                "image/jpeg",
                "110175",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "78",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300659763501.jpg",
                "1468300659763501.jpg",
                "image/jpeg",
                "101921",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "79",
                "http://cms.test.local/uploads/article/thumb/2016071213182356.jpg",
                "2016071213182356.jpg",
                "image/jpeg",
                "91073",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "80",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468301084726130.png",
                "1468301084726130.png",
                "image/png",
                "25212",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "81",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468301084886412.png",
                "1468301084886412.png",
                "image/png",
                "26788",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "82",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468301084537661.png",
                "1468301084537661.png",
                "image/png",
                "107451",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "83",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468301084923297.png",
                "1468301084923297.png",
                "image/png",
                "21920",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "84",
                "http://cms.test.local/uploads/article/thumb/201607121325288.png",
                "201607121325288.png",
                "image/png",
                "25212",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "85",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300778221138.jpg",
                "1468300778221138.jpg",
                "image/jpeg",
                "157573",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "86",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300778457780.jpg",
                "1468300778457780.jpg",
                "image/jpeg",
                "16637",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "87",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300778601199.jpg",
                "1468300778601199.jpg",
                "image/jpeg",
                "72395",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "88",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779717747.jpg",
                "1468300779717747.jpg",
                "image/jpeg",
                "63199",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "89",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779981627.jpg",
                "1468300779981627.jpg",
                "image/jpeg",
                "30848",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "90",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779963476.jpg",
                "1468300779963476.jpg",
                "image/jpeg",
                "149355",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "91",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779231027.jpg",
                "1468300779231027.jpg",
                "image/jpeg",
                "41075",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "92",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779129397.jpg",
                "1468300779129397.jpg",
                "image/jpeg",
                "26673",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "93",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779356792.jpg",
                "1468300779356792.jpg",
                "image/jpeg",
                "70152",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "94",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779474036.jpg",
                "1468300779474036.jpg",
                "image/jpeg",
                "60897",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "95",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779498739.jpg",
                "1468300779498739.jpg",
                "image/jpeg",
                "82173",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "96",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779557053.jpg",
                "1468300779557053.jpg",
                "image/jpeg",
                "20340",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "97",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779956898.jpg",
                "1468300779956898.jpg",
                "image/jpeg",
                "43242",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "98",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779320557.jpg",
                "1468300779320557.jpg",
                "image/jpeg",
                "57723",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "99",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779688267.jpg",
                "1468300779688267.jpg",
                "image/jpeg",
                "39901",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "100",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779821471.jpg",
                "1468300779821471.jpg",
                "image/jpeg",
                "81043",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "101",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300779257195.jpg",
                "1468300779257195.jpg",
                "image/jpeg",
                "50877",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "102",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300780349132.jpg",
                "1468300780349132.jpg",
                "image/jpeg",
                "60352",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "103",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300780975855.jpg",
                "1468300780975855.jpg",
                "image/jpeg",
                "251368",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "104",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300780195077.jpg",
                "1468300780195077.jpg",
                "image/jpeg",
                "15067",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "105",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300780463966.jpg",
                "1468300780463966.jpg",
                "image/jpeg",
                "99269",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "106",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300780198391.jpg",
                "1468300780198391.jpg",
                "image/jpeg",
                "15510",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "107",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300780794205.jpg",
                "1468300780794205.jpg",
                "image/jpeg",
                "113128",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "108",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300780492694.jpg",
                "1468300780492694.jpg",
                "image/jpeg",
                "24182",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "109",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300780436111.jpg",
                "1468300780436111.jpg",
                "image/jpeg",
                "60883",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "110",
                "http://cms.test.local/uploads/article/ueditor/php/upload/image/20160712/1468300780335966.jpg",
                "1468300780335966.jpg",
                "image/jpeg",
                "183215",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "111",
                "http://cms.test.local/uploads/article/thumb/2016071213203123.jpg",
                "2016071213203123.jpg",
                "image/jpeg",
                "157573",
                "1",
                "1476070310",
                "1476070310",

            ],
            [
                "112",
                "http://cms.test.local/uploads/article/thumb/2016071213224495.jpg",
                "2016071213224495.jpg",
                "image/jpeg",
                "6556",
                "1",
                "1476070310",
                "1476070310",

            ],

        ]);

        $this->createTable('{{%file_usage}}', [
            'id' => $this->primaryKey()->unsigned(),
            'fid' => $this->integer()->unsigned()->notNull(),
            'type' => $this->smallInteger()->unsigned()->defaultValue(0),
            'use_id'=> $this->integer()->unsigned()->notNull(),
            'count' => $this->integer()->unsigned()->defaultValue(1),
            'created_at' => $this->integer()->unsigned()->notNull(),
        ], $tableOptions);
        $this->addForeignKey('fk_fid', "{{%file_usage}}", "fid", "{{%file}}", "id", "CASCADE", "CASCADE");
        $this->batchInsert('{{%file_usage}}', ['id','fid','type','use_id','count','created_at'], [
            [
                "1",
                "1",
                "1",
                "1",
                "1",
                "1476070309",

            ],
            [
                "2",
                "2",
                "1",
                "1",
                "1",
                "1476070309",

            ],
            [
                "3",
                "3",
                "1",
                "1",
                "1",
                "1476070309",

            ],
            [
                "4",
                "4",
                "1",
                "1",
                "1",
                "1476070309",

            ],
            [
                "5",
                "5",
                "1",
                "1",
                "1",
                "1476070309",

            ],
            [
                "6",
                "6",
                "1",
                "1",
                "1",
                "1476070309",

            ],
            [
                "7",
                "7",
                "1",
                "1",
                "1",
                "1476070309",

            ],
            [
                "8",
                "8",
                "1",
                "1",
                "1",
                "1476070309",

            ],
            [
                "9",
                "9",
                "1",
                "1",
                "1",
                "1476070309",

            ],
            [
                "10",
                "10",
                "1",
                "1",
                "1",
                "1476070309",

            ],
            [
                "11",
                "11",
                "0",
                "1",
                "1",
                "1476070309",

            ],
            [
                "12",
                "12",
                "1",
                "2",
                "1",
                "1476070310",

            ],
            [
                "13",
                "13",
                "1",
                "2",
                "1",
                "1476070310",

            ],
            [
                "14",
                "14",
                "1",
                "2",
                "1",
                "1476070310",

            ],
            [
                "15",
                "15",
                "1",
                "2",
                "1",
                "1476070310",

            ],
            [
                "16",
                "16",
                "1",
                "2",
                "1",
                "1476070310",

            ],
            [
                "17",
                "17",
                "1",
                "2",
                "1",
                "1476070310",

            ],
            [
                "18",
                "18",
                "0",
                "2",
                "1",
                "1476070310",

            ],
            [
                "19",
                "19",
                "1",
                "3",
                "1",
                "1476070310",

            ],
            [
                "20",
                "20",
                "0",
                "3",
                "1",
                "1476070310",

            ],
            [
                "21",
                "21",
                "1",
                "4",
                "1",
                "1476070310",

            ],
            [
                "22",
                "22",
                "1",
                "4",
                "1",
                "1476070310",

            ],
            [
                "23",
                "23",
                "1",
                "4",
                "1",
                "1476070310",

            ],
            [
                "24",
                "24",
                "1",
                "4",
                "1",
                "1476070310",

            ],
            [
                "25",
                "25",
                "0",
                "4",
                "1",
                "1476070310",

            ],
            [
                "26",
                "26",
                "0",
                "5",
                "1",
                "1476070310",

            ],
            [
                "27",
                "27",
                "1",
                "6",
                "1",
                "1476070310",

            ],
            [
                "28",
                "28",
                "0",
                "6",
                "1",
                "1476070310",

            ],
            [
                "29",
                "29",
                "1",
                "7",
                "1",
                "1476070310",

            ],
            [
                "30",
                "30",
                "0",
                "8",
                "1",
                "1476070310",

            ],
            [
                "31",
                "31",
                "1",
                "9",
                "1",
                "1476070310",

            ],
            [
                "32",
                "32",
                "1",
                "9",
                "1",
                "1476070310",

            ],
            [
                "33",
                "33",
                "1",
                "9",
                "1",
                "1476070310",

            ],
            [
                "34",
                "34",
                "1",
                "9",
                "1",
                "1476070310",

            ],
            [
                "35",
                "35",
                "1",
                "9",
                "1",
                "1476070310",

            ],
            [
                "36",
                "36",
                "0",
                "9",
                "1",
                "1476070310",

            ],
            [
                "37",
                "37",
                "0",
                "10",
                "1",
                "1476070310",

            ],
            [
                "38",
                "38",
                "0",
                "11",
                "1",
                "1476070310",

            ],
            [
                "39",
                "39",
                "0",
                "12",
                "1",
                "1476070310",

            ],
            [
                "40",
                "40",
                "1",
                "13",
                "1",
                "1476070310",

            ],
            [
                "41",
                "41",
                "1",
                "13",
                "1",
                "1476070310",

            ],
            [
                "42",
                "42",
                "1",
                "13",
                "1",
                "1476070310",

            ],
            [
                "43",
                "43",
                "1",
                "13",
                "1",
                "1476070310",

            ],
            [
                "44",
                "44",
                "0",
                "13",
                "1",
                "1476070310",

            ],
            [
                "45",
                "45",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "46",
                "46",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "47",
                "47",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "48",
                "48",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "49",
                "49",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "50",
                "50",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "51",
                "51",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "52",
                "52",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "53",
                "53",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "54",
                "54",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "55",
                "55",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "56",
                "56",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "57",
                "57",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "58",
                "58",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "59",
                "59",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "60",
                "60",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "61",
                "61",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "62",
                "62",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "63",
                "63",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "64",
                "64",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "65",
                "65",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "66",
                "66",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "67",
                "67",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "68",
                "68",
                "1",
                "14",
                "1",
                "1476070310",

            ],
            [
                "69",
                "69",
                "0",
                "15",
                "1",
                "1476070310",

            ],
            [
                "70",
                "70",
                "1",
                "16",
                "1",
                "1476070310",

            ],
            [
                "71",
                "71",
                "1",
                "16",
                "1",
                "1476070310",

            ],
            [
                "72",
                "72",
                "0",
                "16",
                "1",
                "1476070310",

            ],
            [
                "73",
                "73",
                "1",
                "17",
                "1",
                "1476070310",

            ],
            [
                "74",
                "74",
                "1",
                "18",
                "1",
                "1476070310",

            ],
            [
                "75",
                "75",
                "0",
                "18",
                "1",
                "1476070310",

            ],
            [
                "76",
                "76",
                "1",
                "19",
                "1",
                "1476070310",

            ],
            [
                "77",
                "77",
                "1",
                "19",
                "1",
                "1476070310",

            ],
            [
                "78",
                "78",
                "1",
                "19",
                "1",
                "1476070310",

            ],
            [
                "79",
                "79",
                "0",
                "19",
                "1",
                "1476070310",

            ],
            [
                "80",
                "80",
                "1",
                "20",
                "1",
                "1476070310",

            ],
            [
                "81",
                "81",
                "1",
                "20",
                "1",
                "1476070310",

            ],
            [
                "82",
                "82",
                "1",
                "20",
                "1",
                "1476070310",

            ],
            [
                "83",
                "83",
                "1",
                "20",
                "1",
                "1476070310",

            ],
            [
                "84",
                "84",
                "0",
                "20",
                "1",
                "1476070310",

            ],
            [
                "85",
                "85",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "86",
                "86",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "87",
                "87",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "88",
                "88",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "89",
                "89",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "90",
                "90",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "91",
                "91",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "92",
                "92",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "93",
                "93",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "94",
                "94",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "95",
                "95",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "96",
                "96",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "97",
                "97",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "98",
                "98",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "99",
                "99",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "100",
                "100",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "101",
                "101",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "102",
                "102",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "103",
                "103",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "104",
                "104",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "105",
                "105",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "106",
                "106",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "107",
                "107",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "108",
                "108",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "109",
                "109",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "110",
                "110",
                "1",
                "21",
                "1",
                "1476070310",

            ],
            [
                "111",
                "111",
                "0",
                "21",
                "1",
                "1476070310",

            ],
            [
                "112",
                "112",
                "0",
                "22",
                "1",
                "1476070310",

            ],
        ]);
    }

    public function down()
    {
        $this->db->createCommand("set foreign_key_checks=0")->execute(); 
        $this->dropTable('{{%user}}');
        $this->dropTable('{{%admin_log}}');
        $this->dropTable('{{%admin_role_permission}}');
        $this->dropTable('{{%admin_role_user}}');
        $this->dropTable('{{%admin_roles}}');
        $this->dropTable('{{%admin_user}}');
        $this->dropTable('{{%article}}');
        $this->dropTable('{{%article_content}}');
        $this->dropTable('{{%category}}');
        $this->dropTable('{{%comment}}');
        $this->dropTable('{{%friend_link}}');
        $this->dropTable('{{%menu}}');
        //$this->dropTable('{{%migration}}');
        $this->dropTable('{{%options}}');
        $this->dropTable('{{%file%}}');
        $this->dropTable('{{%file_usage}}');
        $this->db->createCommand("set foreign_key_checks=1")->execute();
    }
}
